<?php

namespace Drupal\bug_tracker\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'Report bug' block.
 *
 * @Block(
 *   id = "report_bug",
 *   admin_label = @Translation("Report bug"),
 *   category = @Translation("Custom block"),
 * )
 */
class ReportBugBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'bug_tracker_report_bug_block',
      '#attached' => [
        'library' => [
          'bug_tracker/html2canvas',
          'bug_tracker/cropper',
          'bug_tracker/bug_tracker',
        ],
      ],
      '#statuses_terms' => $this->getBugsTaxonomyTree('bugs_statuses'),
      '#priorities_terms' => $this->getBugsTaxonomyTree('bugs_priorities'),
    ];
  }

  /**
   * Get taxonomy tree by provided vid value.
   *
   * @param $vid
   *   Value to use to load taxonomy tree.
   *
   * @return array
   *   Taxonomy terms.
   */
  private function getBugsTaxonomyTree($vid) {
    $terms = \Drupal::entityTypeManager()
      ->getStorage('taxonomy_term')
      ->loadTree($vid);
    $term_data = [];
    foreach ($terms as $term) {
      $term_data[] = [
        "id" => $term->tid,
        "name" => $term->name
      ];
    }
    return $term_data;
  }

}
